CHANGELOG
=========

1.2.0 - 2025-03-01
------------------

Add size multiplier configuration setting to increase size of all emoji.

Contributed by [Weston Boone](https://github.com/boonew2) via [PR #16](https://github.com/pelican-plugins/pelimoji/pull/16/)


1.1.1 - 2023-12-14
------------------

Switched to fixed CSS class prefix to avoid issues when using default blank prefix

1.1.0 - 2023-12-13
------------------

Fix for path not existing on initial build

1.0.0 - 2023-06-25
------------------

Initial release as namespace plugin
